package com.chinaitop.agile.controller;


import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.service.BusinessSceduleService;
import com.chinaitop.agile.model.BusinessScedule;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 执行进度
 * @author My Sunshine
 *
 */
@RestController
@RequestMapping(value="/agile/scedule")
@Api(value= "BusinessSceduleController", description = "执行进度")

public class BusinessSceduleController {
    
    @Resource
    private BusinessSceduleService businessSceduleService;
    
    /**
	 * 修改出入库系统的 通知单状态.
	 */
	@RequestMapping(value="/updateNoticeStatus", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="修改出入库系统的 通知单状态.", notes = "修改出入库系统的 通知单状态.")
	
    public void updateNoticeStatus(Map<String, Object> paramMap) {
		
      businessSceduleService.updateNoticeStatus(paramMap);
    	
    }
    
	
	/**
	 * 计划执行进度
	 */
	@RequestMapping(value="/getPlanSceduleInPlanId",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="计划执行进度", notes = "计划执行进度")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "计划id", paramType = "query")
    })
    public List<BusinessScedule> getPlanSceduleInPlanId(String planIds) {

         return businessSceduleService.getPlanSceduleInPlanId(planIds);
       
    }
	
	
	/**
	 * 合同执行进度
	 */
	@RequestMapping(value="/getContractSceduleInContractId",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="合同执行进度", notes = "合同执行进度")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "contractIds", value = "合同id", paramType = "query")
	})
	public List<BusinessScedule> getContractSceduleInContractId(String contractIds) {
		
		return businessSceduleService.getContractSceduleInContractId(contractIds);
		
	}
	
	
	/**
	 * 通知单执行进度
	 */
	@RequestMapping(value="/getNoticeSceduleInNoticeId",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="通知单执行进度", notes = "通知单执行进度")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "planIds", value = "通知单id", paramType = "query")
	})
	public List<BusinessScedule> getNoticeSceduleInNoticeId(String noticeIds) {
		
		return businessSceduleService.getNoticeSceduleInNoticeId(noticeIds);
		
	}
	
	
	/**
	 * 到站中转执行进度
	 */
	@RequestMapping(value="/getDzContractSceduleInContractId",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="到站中转执行进度", notes = "到站中转执行进度")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "contractIds", value = "到站中转id", paramType = "query")
	})
	public List<BusinessScedule> getDzContractSceduleInContractId(String contractIds) {
		
		return businessSceduleService.getDzContractSceduleInContractId(contractIds);
		
	}
	
	
	/**
	 * 发运中转执行进度
	 */
	@RequestMapping(value="/getFyContractSceduleInContractId",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="发运中转执行进度", notes = "发运中转执行进度")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "contractIds", value = "发运中转id", paramType = "query")
	})
	public List<BusinessScedule> getFyContractSceduleInContractId(String contractIds) {
		
		return businessSceduleService.getFyContractSceduleInContractId(contractIds);
		
	}
	
	
	/**
	 * 提货单执行进度
	 */
	@RequestMapping(value="/getThdInNumber",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="提货单执行进度", notes = "提货单执行进度")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "thdNumbers", value = "提货单", paramType = "query")
	})
	public List<BusinessScedule> getThdInNumber(String thdNumbers) {
		
		return businessSceduleService.getThdInNumber(thdNumbers);
		
	}
	
}
