package com.chinaitop.agile.controller;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.model.DataKcglFcbgzDefault;
import com.chinaitop.agile.model.DataKcglFcbgzDefaultExample;
import com.chinaitop.agile.model.DataKcglKcswDefault;
import com.chinaitop.agile.service.DataKcglFcbgzDefaultService;
import com.chinaitop.agile.service.KcswService;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/agile/kcsw")
@Api(value= "KcswController", description = "库存实物控制类")
public class KcswController {

	@Resource
	private KcswService kcswService;
	
	@Resource
	private DataKcglFcbgzDefaultService fcbgzService;

    @RequestMapping(value="/getDate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="首页柱形图", notes = "首页柱形图")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
    public Map<String, Object> getDate(Integer orgId) {
        Map<String, Object> queryByExample = null;
		try {
			queryByExample = kcswService.queryByExample(orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
        return queryByExample;
    }

    @RequestMapping(value="/countByBl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询库存总量", notes = "根据库存总量")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
    public Map<String, Object> countByBl(Integer orgId) {
    	Map<String, Object> map = null;
		try {
			map = kcswService.countByBlType(orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return map;
	}

    @RequestMapping(value="/getDateDj", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据1~3等粮食的总数量(首页饼图)", notes = "根据1~3等粮食的总数量(首页饼图)")
	@ApiImplicitParams({
		@ApiImplicitParam(name="orgId", value="单位ID", paramType="query")
	})
    public Map<String, Object> getDateDj(Integer orgId) {
        Map<String, Object> queryByExample = null;
		try {
			queryByExample = kcswService.queryByDj(orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
        return queryByExample;
    }

    @RequestMapping(value="/getDateBl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询库存库容比(首页仪表盘)", notes = "查询库存库容比(首页仪表盘)")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "effectiveCapacity", value = "有效仓容", paramType = "query"),
		@ApiImplicitParam(name="orgId", value="单位ID", paramType="query")
	})
    public String getDateBl(String effectiveCapacity, Integer orgId) {
    	Map<String, Object> map = new HashMap<String, Object>();
        String queryByBl = "";
		try {
			map.put("orgId", orgId);
			queryByBl = kcswService.queryByBl(effectiveCapacity, map);
		} catch (Exception e) {
			e.printStackTrace();
		}
        if(StringUtils.isNotBlank(queryByBl)){
        	return queryByBl;
        }
        return null;
    }

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="库存数量管理列表数据查询", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kcswStr", value = "条件集合", paramType = "query"),
        @ApiImplicitParam(name = "order", value = "排序方式", paramType = "query"),
        @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
    public PageInfo<DataKcglKcswDefault> getList(Integer pageNum, Integer pageSize, String kcswStr,
    		String order, Integer orgId){
    	PageInfo<DataKcglKcswDefault> pageInfo = null;
		try {
			pageInfo = kcswService.queryYYSSL(pageNum, pageSize, kcswStr, order, orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
    	return pageInfo;
    }
	
	@RequestMapping(value="/importList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="导出库存数量数据为Excel", notes = "")
	@ApiImplicitParams({
        @ApiImplicitParam(name = "kcswStr", value = "条件集合", paramType = "query"),
        @ApiImplicitParam(name = "order", value = "排序方式", paramType = "query")
	})
    public List<DataKcglKcswDefault> importList(HttpServletRequest request, HttpServletResponse response, String kcswStr, String order){
    	List<DataKcglKcswDefault> list = null;
		try {
			list = kcswService.importList(request, response, kcswStr, order);
		} catch (Exception e) {
			e.printStackTrace();
		}
    	return list;
    }

    @RequestMapping(value="/getHouseOrWareList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取仓房或者货位", notes = "仓房或者货位")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "list", value = "符合轮换计划的第三方检查的数据", paramType = "query")
	})
    public List<Integer> getHouseIdList(String list,Integer orgId) {
        List<Integer> list1 = null;
        try {
			list1 = kcswService.getHouseIdList(list, orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
        return list1;
    }

    @RequestMapping(value="/getCount", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取数量", notes = "获取数量")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "groupByClause", value = "类型", paramType = "query")
	})
    public Map<String, Object> getCount(String groupByClause) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        List<Map<String, Object>> resultList = new ArrayList<>();
        try {
			if (groupByClause.compareTo("pz")==0) {
			    resultList = kcswService.selectCountByPz();
			}
			if (groupByClause.compareTo("xz")==0) {
			    resultList = kcswService.selectCountByXz();
			}
			if (groupByClause.compareTo("year")==0) {
			    resultList = kcswService.selectCountByYear();
			}
			if (groupByClause.compareTo("city")==0) {
			    resultList = kcswService.selectCountByCity();
			}
			modelMap.put("result", resultList);
		} catch (Exception e) {
			e.printStackTrace();
		}
        return modelMap;
    }
    
    /**
     * 获取库存数量
     * @param storehouseId 仓房id
     * @param warehouseId 货位id
     * @return
     * @throws Exception 
     */
    @RequestMapping(value="/getMassageBych", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取库存数量", notes = "获取库存数量")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "storehouseId", value = "仓房id", paramType = "query"),
		@ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
		@ApiImplicitParam(name = "qualitycheckList", value = "货位id", paramType = "query"),
	})
    public Map<String, Object> getMassageBych(Integer storehouseId,Integer warehouseId,String qualitycheckList) throws Exception {
    	Map<String, Object> map = new HashMap<String, Object>();
    	if(storehouseId!=null && warehouseId!=null){
    		Map<String, Object> modelMap = new HashMap<String, Object>();
        	modelMap.put("storehouseId", storehouseId);
        	modelMap.put("warehouseId", warehouseId);
        	List<DataKcglKcswDefault> list = kcswService.getMassageBych(modelMap);
        	//给生产年份赋值
    		if (null != list && list.size() > 0) {
    			for (DataKcglKcswDefault dataKcglKcswDefault : list) {
    				DataKcglFcbgzDefaultExample fcbgz_example = new DataKcglFcbgzDefaultExample();
    				DataKcglFcbgzDefaultExample.Criteria fcbgz_criteria = fcbgz_example.createCriteria();
    				fcbgz_criteria.andUnitidEqualTo(dataKcglKcswDefault.getUnitid());
    				fcbgz_criteria.andChEqualTo(dataKcglKcswDefault.getCh());
    				fcbgz_criteria.andHwhEqualTo(dataKcglKcswDefault.getHwh());
    				fcbgz_criteria.andSrslGreaterThan(0d);//收入数量大于0
    				fcbgz_example.setOrderByClause(" rq DESC");
    				List<DataKcglFcbgzDefault> fcbgz_list = fcbgzService.findByList(fcbgz_example);
    				if (null != fcbgz_list && fcbgz_list.size() > 0) {
    					int scnf = Integer.parseInt(ObjectUtils.toString(fcbgz_list.get(0).getScnf(), "0"));
    					dataKcglKcswDefault.setScnf(scnf);
    				}
    			}
    		}
        	map.put("list", list);
    	}

    	if(qualitycheckList!=null){
    		map.put("qualitycheckList", qualitycheckList);
    	}
    	
    	
    	return map;
    }

	@RequestMapping(value="/queryLKNewData",produces=MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询出入库信息", notes = "查询出入库最新粮库储粮信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
	public List<DataKcglKcswDefault> queryLKNewData(Integer orgId) {
		Map<String, Object> map = new HashMap<String, Object>();
		List<DataKcglKcswDefault> list = null;
		try {
			if (null != orgId) {
				map.put("orgId", orgId.toString());
			}
			list = kcswService.queryLKNewData(map);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return list;
	}

	@RequestMapping(value="/getWarningList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取仓房或者货位", notes = "仓房或者货位")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "days", value = "提前几天提醒", paramType = "query"),
		@ApiImplicitParam(name = "list", value = "集合", paramType = "query")
	})
	public PageInfo<DataKcglKcswDefault> getHouseIdList(Integer pageNum, Integer pageSize,Integer days,String list,DataKcglKcswDefault kcsw, Integer orgId) {

        if(pageNum!=null && pageSize!=null){
            PageHelper.startPage(pageNum, pageSize);
        }
        List<DataKcglKcswDefault> olist = null;
        PageInfo<DataKcglKcswDefault> pageInfo = null;
        try {
			olist = kcswService.getHouseIdList(days, list, kcsw, orgId);
			pageInfo = new PageInfo<DataKcglKcswDefault>(olist);
			if(pageInfo.getTotal()>0){
				pageInfo.setStartRow(pageInfo.getStartRow()+1);
				pageInfo.setEndRow(pageInfo.getEndRow()+1);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
        return pageInfo;
    
	}

	@RequestMapping(value="/emptyKcsw", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="获取仓房或者货位", notes = "仓房或者货位")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "userInfo", value = "登录对象", paramType = "form"),
		@ApiImplicitParam(name = "profitlossSheet", value = "损益单对象", paramType = "form")
	})
	public Map<String, Object> emptyKcsw(String userInfo, String profitlossSheet) {

		Map<String, Object> map = new HashMap<String, Object>();

		/* 更新分仓保管账表、形成库存表、库存实物表  */
		try {
			kcswService.updateKc(userInfo, profitlossSheet);
		} catch (Exception e) {
			e.printStackTrace();
		}

		return map;
	}
	
	
	/**
	 * 销售计划 查询当前组织的库存信息
	 * @throws Exception 
	 */
	@RequestMapping(value="/queryKcData",produces=MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询当前组织的库存信息", notes = "查询当前组织的库存信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "form"),
		@ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "form"),
		@ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "form")
	})
	public List<DataKcglKcswDefault> queryKcData(Integer orgId, Integer houseId, Integer warehouseId) throws Exception{
		List<DataKcglKcswDefault> kcList = kcswService.queryKcData(orgId,houseId,warehouseId);
		//给生产年份赋值
		if (null != kcList && kcList.size() > 0) {
			for (DataKcglKcswDefault dataKcglKcswDefault : kcList) {
				DataKcglFcbgzDefaultExample fcbgz_example = new DataKcglFcbgzDefaultExample();
				DataKcglFcbgzDefaultExample.Criteria fcbgz_criteria = fcbgz_example.createCriteria();
				fcbgz_criteria.andUnitidEqualTo(dataKcglKcswDefault.getUnitid());
				fcbgz_criteria.andChEqualTo(dataKcglKcswDefault.getCh());
				fcbgz_criteria.andHwhEqualTo(dataKcglKcswDefault.getHwh());
				fcbgz_criteria.andSrslGreaterThan(0d);//收入数量大于0
				fcbgz_example.setOrderByClause(" rq DESC");
				List<DataKcglFcbgzDefault> fcbgz_list = fcbgzService.findByList(fcbgz_example);
				if (null != fcbgz_list && fcbgz_list.size() > 0) {
					int scnf = Integer.parseInt(ObjectUtils.toString(fcbgz_list.get(0).getScnf(), "0"));
					dataKcglKcswDefault.setScnf(scnf);
				}
			}
		}
		
		return kcList;
	}

	@RequestMapping(value="/queryKcswData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="库存实物记录查询", notes = "库存实物记录查询")
	@ApiImplicitParams({
		@ApiImplicitParam(name="datas", value="条件", paramType="query"),
		@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query")
	})
	public List<Map<String, Object>> queryKcswData(String datas, String orgId) {

		ObjectMapper mapper = new ObjectMapper();
		List<Map<String, Object>> result_list = new ArrayList<Map<String, Object>>();

		DataKcglKcswDefault kcsw = null;
		Map<String, Object> param_map = null;
		List<Map<String, Object>> list = null;
		try {
			List<DataKcglKcswDefault> param_List = mapper.readValue(datas, new TypeReference<List<DataKcglKcswDefault>>(){});
			if (null != param_List && param_List.size() > 0) {
				for (DataKcglKcswDefault obj : param_List) {
					kcsw = obj;
					param_map = new HashMap<String, Object>();

					/* 单位 */
					if (StringUtils.isNotBlank(orgId)) {
						param_map.put("orgId", orgId);
					}

					/* 货位 */
					if (null != kcsw.getHwh()) {
						param_map.put("wareId", kcsw.getHwh());
					}

					list = kcswService.findAgentCondition(param_map);
					//给生产年份赋值
					if (null != list && list.size() > 0) {
						Map<String, Object> obj1 = null;
						for (int i = list.size()-1; i >= 0; i--) {
							//obj1.setOlddataid(ParameterUtil.date2string(obj1.get("")));
							obj1 = list.get(i);
							result_list.add(obj1);
						}
					}
				}
			}
			

		} catch (Exception e1) {
			e1.printStackTrace();
		}

		return result_list;
	}

	/**
	 * 根据orgId、仓房、货位 获取其他相关信息,用于市库对接
	 */
	@RequestMapping(value="/getDateByChHwh", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据orgId、仓房、货位 获取其他相关信息", notes = "根据orgId、仓房、货位 获取其他相关信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name="orgId", value="单位ID", paramType="query"),
		@ApiImplicitParam(name="houseId", value="单位ID", paramType="query"),
		@ApiImplicitParam(name="wareHouseId", value="单位ID", paramType="query")
	})
    public Map<String, Object> getDateByChHwh(String orgId,String houseId,String wareHouseId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();

    	try {
			modelMap = kcswService.getDateByChHwh(orgId, houseId, wareHouseId);
		} catch (Exception e) {
			e.printStackTrace();
		}

        return modelMap;
    }
	
	/**
	 * 轮换计划 查询当前库符合条件的轮换计划
	 */
	@RequestMapping(value="/queryLhData",produces=MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询当前库符合条件的轮换计划", notes = "查询当前库符合条件的轮换计划")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "登录对象的orgId", paramType = "form")
	})
	public List<DataKcglKcswDefault> queryLhData(Integer orgId){
		Map<String, Object> modelMap = new HashMap<>();
        modelMap.put("UnitID", orgId);
        List<DataKcglKcswDefault> list = null;
        try {
			list = kcswService.getHouseOrWareList(modelMap);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return list;
	}

	@RequestMapping(value="/getListOrRcsj", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件查询库存实物表数据", notes = "支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "kcswStr", value = "条件集合", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
	public List<DataKcglKcswDefault> getListOrRcsj(String kcswStr, String orgId){
		ObjectMapper mapper = new ObjectMapper();
		DataKcglKcswDefault kcsw = null;
		List<DataKcglKcswDefault> list = null;
		try {
			if (null != kcswStr && !"".equals(kcswStr)) {
				kcsw = mapper.readValue(kcswStr, DataKcglKcswDefault.class);
			} else {
				kcsw = new DataKcglKcswDefault();
			}

			Map<String, Object> modelMap = new HashMap<String, Object>();

			/* 仓房 */
			if (null != kcsw.getCh() && !"".equals(kcsw.getCh())) {
				modelMap.put("ch", kcsw.getCh().toString());
			}
			/* 货位 */
			if (null != kcsw.getHwh() && !"".equals(kcsw.getHwh())) {
				modelMap.put("hwh", kcsw.getHwh().toString());
			}
			/* 单位 */
			if (null != orgId && !"".equals(orgId)) {
				modelMap.put("unitid", orgId);
			}

			list = kcswService.findListOrRcsj(modelMap);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return list;
	}

	@RequestMapping(value="/queryFkcfData",produces=MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询当前库下非空仓房列表和仓房中的库存数据", notes = "")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "orgId", value = "登录对象的orgId", paramType = "query"),
			@ApiImplicitParam(name = "ch", value = "仓房ID", paramType = "query")
	})
	public Map<String, Object> queryFkcfData(String orgId, Integer ch) {
		Map<String, Object> modelMap = new HashMap<>();
		if (StringUtils.isBlank(orgId)) {
			modelMap.put("status", "error");
			modelMap.put("msg", "参数异常，单位不能为空");
			return modelMap;
		}
		try {
			modelMap = kcswService.queryFkcfData(orgId, ch);
		} catch (Exception e) {
			modelMap.put("status", "error");
			modelMap.put("msg", "请求异常");
			e.printStackTrace();
		}
		return modelMap;
	}

}
